# Sandcraft
Sandcraft is a 2D physics-based, particle simulator game where players can interact with different elements to create fun combinations and results!

## Installation
To play Sandcraft:
1. Download and unzip the GitHub repository to a local directory
2. Within the directory run `pip3 install .` to install the `sandcraft` package
3. From the command line, type `play-sandcraft` to run

## Links
GitHub: https://github.com/jonathansessa/Sandcraft  
Trello (Issue Tracker): https://trello.com/b/qNsYidQG/sandcraft

## About
Sandcraft is currently being developed for the Summer 2021 semester of CIS4930: Performant Programming in Python at the University of Florida by Team SiO2:
- John Hook (https://github.com/jhook1)
- Anthony Kane (https://github.com/anthonyvkane)
- Levi Mutter (https://github.com/lmutter)
- Jonathan Sessa (https://github.com/jonathansessa)
- Lukas Vaiciunas (https://github.com/lukas-vaiciunas)
